@@ -84,6 +84,7 @@ __all__ = (
     "ProxyConfigurationTypeDef",
     "TaskDefinitionPlacementConstraintTypeDef",
     "DockerVolumeConfigurationTypeDef",
+    "EFSAuthorizationConfigTypeDef",
     "EFSVolumeConfigurationTypeDef",
     "HostVolumePropertiesTypeDef",
     "VolumeTypeDef",
@@ -737,11 +738,24 @@ DockerVolumeConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+EFSAuthorizationConfigTypeDef = TypedDict(
+    "EFSAuthorizationConfigTypeDef",
+    {"accessPointId": str, "iam": Literal["ENABLED", "DISABLED"]},
+    total=False,
+)
+
 _RequiredEFSVolumeConfigurationTypeDef = TypedDict(
     "_RequiredEFSVolumeConfigurationTypeDef", {"fileSystemId": str}
 )
 _OptionalEFSVolumeConfigurationTypeDef = TypedDict(
-    "_OptionalEFSVolumeConfigurationTypeDef", {"rootDirectory": str}, total=False
+    "_OptionalEFSVolumeConfigurationTypeDef",
+    {
+        "rootDirectory": str,
+        "transitEncryption": Literal["ENABLED", "DISABLED"],
+        "transitEncryptionPort": int,
+        "authorizationConfig": EFSAuthorizationConfigTypeDef,
+    },
+    total=False,
 )
 
 
